@@ -194,7 +194,12 @@ void Doctor::parseOutputArgs()
                         return;
                     }
                 }
-                if (ops.count() == 3 && ops[2] == QLatin1String("enable")) {
+                if (ops.count() == 3 && ops[2] == QLatin1String("primary")) {
+                    if (!setPrimary(output_id)) {
+                        qApp->exit(1);
+                        return;
+                    };
+                } else if (ops.count() == 3 && ops[2] == QLatin1String("enable")) {
                     if (!setEnabled(output_id, true)) {
                         qApp->exit(1);
                         return;
@@ -238,7 +243,7 @@ void Doctor::parseOutputArgs()
                     // be lenient about . vs. comma as separator
                     qreal scale = ops[3].replace(QLatin1Char(','), QLatin1Char('.')).toDouble(&ok);
                     if (ops.count() == 5) {
-                        const QString dbl = ops[3] + QLatin1String(".") + ops[4];
+                        const QString dbl = ops[3] + QStringLiteral(".") + ops[4];
                         scale = dbl.toDouble(&ok);
                     };
                     // set scale
@@ -385,9 +390,9 @@ void Doctor::showOutputs() const
 
     for (const auto &output : m_config->outputs()) {
         cout << green << "Output: " << cr << output->id() << " " << output->name();
-        cout << " " << (output->isEnabled() ? green + QLatin1String("enabled") : red + QLatin1String("disabled"));
-        cout << " " << (output->isConnected() ? green + QLatin1String("connected") : red + QLatin1String("disconnected"));
-        cout << " " << (output->isPrimary() ? green + QLatin1String("primary") : QString());
+        cout << " " << (output->isEnabled() ? green + QStringLiteral("enabled") : red + QStringLiteral("disabled"));
+        cout << " " << (output->isConnected() ? green + QStringLiteral("connected") : red + QStringLiteral("disconnected"));
+        cout << " " << (output->isPrimary() ? green + QStringLiteral("primary") : QString());
         auto _type = typeString[output->type()];
         cout << " " << yellow << (_type.isEmpty() ? QStringLiteral("UnmappedOutputType") : _type);
         cout << blue << " Modes: " << cr;
@@ -506,7 +511,7 @@ bool Doctor::setMode(int id, const QString &mode_id)
     for (const auto &output : m_config->outputs()) {
         if (output->id() == id) {
             // find mode
-            for (const KScreen::ModePtr mode : output->modes()) {
+            for (const KScreen::ModePtr &mode : output->modes()) {
                 auto name =
                     QStringLiteral("%1x%2@%3")
                         .arg(QString::number(mode->size().width()), QString::number(mode->size().height()), QString::number(qRound(mode->refreshRate())));
@@ -613,6 +618,32 @@ bool Doctor::setRgbRange(int id, KScreen::Output::RgbRange rgbRange)
     return false;
 }
 
+bool KScreen::Doctor::setPrimary(int id)
+{
+    if (!m_config) {
+        qCWarning(KSCREEN_DOCTOR) << "Invalid config.";
+        return false;
+    }
+
+    bool found = false;
+    for (const auto &output : m_config->outputs()) {
+        if (output->id() == id) {
+            output->setPrimary(true);
+            m_changed = true;
+            found = true;
+        }
+    }
+    if (found) {
+        for (const auto &output : m_config->outputs()) {
+            if (output->id() != id) {
+                output->setPrimary(false);
+                m_changed = true;
+            }
+        }
+    }
+    return found;
+}
+
 void Doctor::applyConfig()
 {
     if (!m_changed) {
